bayespy.inference.vmp.nodes.deterministic.Deterministic.plot
============================================================

.. currentmodule:: bayespy.inference.vmp.nodes.deterministic

.. automethod:: Deterministic.plot